==> collective.dancefloor-1.0.0.zip: collective.dancefloor-1.0.0/setup.py <==
from setuptools import setup, find_packages
import os

version = '1.0.0'

tests_require = ['plone.app.testing']

setup(name='collective.dancefloor',
      version=version,
      description="S&D extension to allow local newsletters",
      long_description=open("README.rst").read() + "\n" +
                       open(os.path.join("docs", "HISTORY.txt")).read(),
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Framework :: Plone",
        "Programming Language :: Python",
        "Framework :: Plone",
        "Framework :: Plone :: 3.3",
        "Framework :: Plone :: 4.0",
        "Framework :: Plone :: 4.2",
        'Development Status :: 4 - Beta',
        "Topic :: Software Development :: Libraries :: Python Modules",
        ],
      keywords='',
      author='Andrea Cecchi, Ramon Bartl, Stefan Eletzhofer',
      author_email='andrea.cecchi@redturtle.it, ramon.bartl@inquant.de, stefan.eletzhofer@inquant.de',
      url='https://svn.plone.org/svn/collective/collective.dancefloor/trunk',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['collective'],
      include_package_data=True,
      zip_safe=False,
      tests_require=tests_require,
      extras_require=dict(test=tests_require),
      install_requires=[
          'setuptools',
          'collective.dancing',
          'archetypes.schemaextender',
          'collective.monkeypatcher',
      ],
      entry_points="""
      # -*- entry_points -*-
      [z3c.autoinclude.plugin]
      target = plone
      """,
      )

==> collective.dancefloor-1.0.1.zip: collective.dancefloor-1.0.1/setup.py <==
from setuptools import setup, find_packages
import os

version = '1.0.1'

tests_require = ['plone.app.testing']

setup(name='collective.dancefloor',
      version=version,
      description="S&D extension to allow local newsletters",
      long_description=open("README.rst").read() + "\n" +
                       open(os.path.join("docs", "HISTORY.txt")).read(),
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Framework :: Plone",
        "Programming Language :: Python",
        "Framework :: Plone",
        "Framework :: Plone :: 3.3",
        "Framework :: Plone :: 4.0",
        "Framework :: Plone :: 4.2",
        'Development Status :: 4 - Beta',
        "Topic :: Software Development :: Libraries :: Python Modules",
        ],
      keywords='',
      author='RedTurtle Technology',
      author_email='sviluppoplone@redturtle.it',
      url='https://svn.plone.org/svn/collective/collective.dancefloor/trunk',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['collective'],
      include_package_data=True,
      zip_safe=False,
      tests_require=tests_require,
      extras_require=dict(test=tests_require),
      install_requires=[
          'setuptools',
          'collective.dancing',
          'archetypes.schemaextender',
          'collective.monkeypatcher',
      ],
      entry_points="""
      # -*- entry_points -*-
      [z3c.autoinclude.plugin]
      target = plone
      """,
      )
